@@ -8,9 +8,11 @@ import time
 class ZWaveMe:
     """Main controller class"""
 
-    def __init__(self, on_device_create, on_device_update, url, token, platforms=None):
+    def __init__(self, on_device_create, on_device_update, on_new_device,
+                 url, token, platforms=None):
         self.on_device_create = on_device_create
         self.on_device_update = on_device_update
+        self.on_new_device = on_new_device
         self.url = url
         self.token = token
         self.platforms = platforms
@@ -18,6 +20,7 @@ class ZWaveMe:
         self._wshost = None
         self.start_ws()
         self.thread = None
+        self.devices = []
 
     def start_ws(self):
         """get/find the websocket host"""
@@ -40,6 +43,21 @@ class ZWaveMe:
             )
         )
 
+    def get_device_info(self, device_id):
+        self._ws.send(
+            json.dumps(
+                {
+                    "event": "httpEncapsulatedRequest",
+                    "data": {
+                        "method": "GET",
+                        "url": "/ZAutomation/api/v1/devices/{}".format(
+                            device_id
+                        )
+                    }
+                }
+            )
+        )
+
     def init_websocket(self):
         # keep websocket open indefinitely
         while True:
@@ -66,16 +84,24 @@ class ZWaveMe:
             try:
                 if dict_data["type"] == "ws-reply":
                     body = json.loads(dict_data["data"]["body"])
-                    if body["data"]:
-                        devices = [
+                    if "devices" in body["data"]:
+                        self.devices = [
                             device
                             for device in body["data"]["devices"]
                             if device["deviceType"] in self.platforms
                         ]
-                        self.on_device_create(devices)
+                        self.on_device_create(self.devices)
+                    elif "id" in body['data']:
+                        self.on_new_device(body['data'])
                 elif dict_data["type"] == "me.z-wave.devices.level":
                     self.on_device_update(dict_data["data"])
-
+                elif dict_data["type"] == "me.z-wave.namespaces.update":
+                    for data in dict_data['data']:
+                        if data['id'] == 'devices_all':
+                            new_devices = [x['deviceId'] for x in data['params']]
+                            devices_to_install = set(new_devices)-set([x['id'] for x in self.devices])
+                            for device in devices_to_install:
+                                self.get_device_info(device)
             except Exception as e:
                 pass
 
